View Source ExOAPI.Stripe.Schemas.AccountRequirements (exoapi_stripe v0.1.4)
::alternatives :: ExOAPI.Stripe.Schemas.AccountRequirementsAlternative
:current_deadline :: :integer
Date by which the fields in currently_due must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.
::currently_due :: :string
:disabled_reason :: :string
If the account is disabled, this string describes why. Can be requirements.past_due, requirements.pending_verification, listed, platform_paused, rejected.fraud, rejected.listed, rejected.terms_of_service, rejected.other, under_review, or other.
::errors :: ExOAPI.Stripe.Schemas.AccountRequirementsError
::eventually_due :: :string
::past_due :: :string
::pending_verification :: :string
Link to this section Summary
Link to this section Types
@type params() :: map()
@type t() :: %ExOAPI.Stripe.Schemas.AccountRequirements{ alternatives: [ExOAPI.Stripe.Schemas.AccountRequirementsAlternative.t()], current_deadline: integer() | nil, currently_due: [String.t()] | nil, disabled_reason: String.t() | nil, errors: [ExOAPI.Stripe.Schemas.AccountRequirementsError.t()], eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()