View Source ExOAPI.Stripe.Schemas.BillingPortal_configuration (exoapi_stripe v0.1.4)
description: A portal configuration describes the functionality and behavior of a portal session.
:active :: :boolean
Whether the configuration is active and can be used to create portal sessions.
:application :: ExOAPI.Stripe.Schemas.Application
ID of the Connect Application that created the configuration.
:business_profile :: ExOAPI.Stripe.Schemas.PortalBusinessProfile
:created :: :integer
Time at which the object was created. Measured in seconds since the Unix epoch.
:default_return_url :: :string
The default URL to redirect customers to when they click on the portal's link to return to your website. This can be overriden when creating the session.
:features :: ExOAPI.Stripe.Schemas.PortalFeatures
:id :: :string
Unique identifier for the object.
:is_default :: :boolean
Whether the configuration is the default. If true, this configuration can be managed in the Dashboard and portal sessions will use this configuration unless it is overriden when creating the session.
:livemode :: :boolean
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
:metadata :: :map
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
:object :: :string
String representing the object's type. Objects of the same type share the same value.
:updated :: :integer
Time at which the object was last updated. Measured in seconds since the Unix epoch.
Link to this section Summary
Link to this section Types
@type params() :: map()
@type t() :: %ExOAPI.Stripe.Schemas.BillingPortal_configuration{ active: boolean() | nil, application: String.t() | nil, business_profile: ExOAPI.Stripe.Schemas.PortalBusinessProfile.t() | nil, created: integer() | nil, default_return_url: String.t() | nil, features: ExOAPI.Stripe.Schemas.PortalFeatures.t() | nil, id: String.t() | nil, is_default: boolean() | nil, livemode: boolean() | nil, metadata: map() | nil, object: :"billing_portal.configuration" | nil, updated: integer() | nil }
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()