View Source ExOAPI.Stripe.Schemas.DeliveryEstimate (exoapi_stripe v0.1.4)
:date :: :string
If type is "exact", date will be the expected delivery date in the format YYYY-MM-DD.
:earliest :: :string
If type is "range", earliest will be be the earliest delivery date in the format YYYY-MM-DD.
:latest :: :string
If type is "range", latest will be the latest delivery date in the format YYYY-MM-DD.
:type :: :string
The type of estimate. Must be either "range" or "exact".
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()