View Source ExOAPI.Stripe.Schemas.DisputeEvidenceDetails (exoapi_stripe v0.1.4)
:due_by :: :integer
Date by which evidence must be submitted in order to successfully challenge dispute. Will be null if the customer's bank or credit card company doesn't allow a response for this particular dispute.
:has_evidence :: :boolean
Whether evidence has been staged for this dispute.
:past_due :: :boolean
Whether the last evidence submission was submitted past the due date. Defaults to false if no evidence submissions have occurred. If true, then delivery of the latest evidence is not guaranteed.
:submission_count :: :integer
The number of times evidence has been submitted. Typically, you may only submit evidence once.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()