View Source ExOAPI.Stripe.Schemas.InvoiceMandateOptionsCard (exoapi_stripe v0.1.4)
:amount :: :integer
Amount to be charged for future payments.
:amount_type :: :string
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
:description :: :string
A description of the mandate or subscription that is meant to be displayed to the customer.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()