View Source ExOAPI.Stripe.Schemas.IssuingTransactionFuelData (exoapi_stripe v0.1.4)
:type :: :string
The type of fuel that was purchased. One of diesel, unleaded_plus, unleaded_regular, unleaded_super, or other.
:unit :: :string
The units for volume_decimal. One of us_gallon or liter.
:unit_cost_decimal :: :string
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
:volume_decimal :: :string
The volume of the fuel that was pumped, represented as a decimal string with at most 12 decimal places.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()