View Source ExOAPI.Stripe.Schemas.LegalEntityCompanyVerificationDocument (exoapi_stripe v0.1.4)
:back :: ExOAPI.Stripe.Schemas.File | :string
The back of a document returned by a file upload with a purpose value of additional_verification.
:details :: :string
A user-displayable string describing the verification state of this document.
:details_code :: :string
One of document_corrupt, document_expired, document_failed_copy, document_failed_greyscale, document_failed_other, document_failed_test_mode, document_fraudulent, document_incomplete, document_invalid, document_manipulated, document_not_readable, document_not_uploaded, document_type_not_supported, or document_too_large. A machine-readable code specifying the verification state for this document.
:front :: ExOAPI.Stripe.Schemas.File | :string
The front of a document returned by a file upload with a purpose value of additional_verification.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()