View Source ExOAPI.Stripe.Schemas.LegalEntityPersonVerificationDocument (exoapi_stripe v0.1.4)
:back :: ExOAPI.Stripe.Schemas.File | :string
The back of an ID returned by a file upload with a purpose value of identity_document.
:details :: :string
A user-displayable string describing the verification state of this document. For example, if a document is uploaded and the picture is too fuzzy, this may say "Identity document is too unclear to read".
:details_code :: :string
One of document_corrupt, document_country_not_supported, document_expired, document_failed_copy, document_failed_other, document_failed_test_mode, document_fraudulent, document_failed_greyscale, document_incomplete, document_invalid, document_manipulated, document_missing_back, document_missing_front, document_not_readable, document_not_uploaded, document_photo_mismatch, document_too_large, or document_type_not_supported. A machine-readable code specifying the verification state for this document.
:front :: ExOAPI.Stripe.Schemas.File | :string
The front of an ID returned by a file upload with a purpose value of identity_document.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()