View Source ExOAPI.Stripe.Schemas.Price (exoapi_stripe v0.1.4)
description: Prices define the unit cost, currency, and (optional) billing cycle for both recurring and one-time purchases of products. Products help you track inventory or provisioning, and prices help you track payment terms. Different physical goods or levels of service should be represented by products, and pricing options should be represented by prices. This approach lets you change prices without having to change your provisioning scheme.
For example, you might have a single "gold" product that has prices for $10/month, $100/year, and €9 once.
Related guides: Set up a subscription, create an invoice, and more about products and prices.
:active :: :boolean
Whether the price can be used for new purchases.
:billing_scheme :: :string
Describes how to compute the price per period. Either per_unit or tiered. per_unit indicates that the fixed amount (specified in unit_amount or unit_amount_decimal) will be charged per unit in quantity (for prices with usage_type=licensed), or per unit of total usage (for prices with usage_type=metered). tiered indicates that the unit pricing will be computed using a tiering strategy as defined using the tiers and tiers_mode attributes.
:created :: :integer
Time at which the object was created. Measured in seconds since the Unix epoch.
:currency :: :string
Three-letter ISO currency code, in lowercase. Must be a supported currency.
:id :: :string
Unique identifier for the object.
:livemode :: :boolean
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
:lookup_key :: :string
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
:metadata :: :map
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
:nickname :: :string
A brief description of the price, hidden from customers.
:object :: :string
String representing the object's type. Objects of the same type share the same value.
:product :: ExOAPI.Stripe.Schemas.DeletedProduct | ExOAPI.Stripe.Schemas.Product | :string
The ID of the product this price is associated with.
:recurring :: ExOAPI.Stripe.Schemas.Recurring
The recurring components of a price such as interval and usage_type.
:tax_behavior :: :string
Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
::tiers :: ExOAPI.Stripe.Schemas.PriceTier
:tiers_mode :: :string
Defines if the tiering price should be graduated or volume based. In volume-based tiering, the maximum quantity within a period determines the per unit price. In graduated tiering, pricing can change as the quantity grows.
:transform_quantity :: ExOAPI.Stripe.Schemas.TransformQuantity
Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with tiers.
:type :: :string
One of one_time or recurring depending on whether the price is for a one-time purchase or a recurring (subscription) purchase.
:unit_amount :: :integer
The unit amount in %s to be charged, represented as a whole integer if possible. Only set if billing_scheme=per_unit.
:unit_amount_decimal :: :string
The unit amount in %s to be charged, represented as a decimal string with at most 12 decimal places. Only set if billing_scheme=per_unit.
Link to this section Summary
Link to this section Types
@type params() :: map()
@type t() :: %ExOAPI.Stripe.Schemas.Price{ active: boolean() | nil, billing_scheme: (:tiered | :per_unit) | nil, created: integer() | nil, currency: String.t() | nil, id: String.t() | nil, livemode: boolean() | nil, lookup_key: String.t() | nil, metadata: map() | nil, nickname: String.t() | nil, object: :price | nil, product: ExOAPI.EctoTypes.AnyOf.t() | nil, recurring: ExOAPI.EctoTypes.AnyOf.t() | nil, tax_behavior: (:unspecified | :inclusive | :exclusive) | nil, tiers: [ExOAPI.Stripe.Schemas.PriceTier.t()], tiers_mode: (:volume | :graduated) | nil, transform_quantity: ExOAPI.EctoTypes.AnyOf.t() | nil, type: (:recurring | :one_time) | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil }
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()