View Source ExOAPI.Stripe.Schemas.SetupIntentPaymentMethodOptionsCardMandateOptions (exoapi_stripe v0.1.4)
:amount :: :integer
Amount to be charged for future payments.
:amount_type :: :string
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
:currency :: :string
Three-letter ISO currency code, in lowercase. Must be a supported currency.
:description :: :string
A description of the mandate or subscription that is meant to be displayed to the customer.
:end_date :: :integer
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
:interval :: :string
Specifies payment frequency. One of day, week, month, year, or sporadic.
:interval_count :: :integer
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
:reference :: :string
Unique identifier for the mandate or subscription.
:start_date :: :integer
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
::supported_types :: :string
Link to this section Summary
Link to this section Types
@type params() :: map()
@type t() :: %ExOAPI.Stripe.Schemas.SetupIntentPaymentMethodOptionsCardMandateOptions{ amount: integer() | nil, amount_type: (:maximum | :fixed) | nil, currency: String.t() | nil, description: String.t() | nil, end_date: integer() | nil, interval: (:year | :week | :sporadic | :month | :day) | nil, interval_count: integer() | nil, reference: String.t() | nil, start_date: integer() | nil, supported_types: [String.t()] | nil }
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()