View Source ExOAPI.Stripe.Schemas.SkuInventory (exoapi_stripe v0.1.4)
:quantity :: :integer
The count of inventory available. Will be present if and only if type is finite.
:type :: :string
Inventory type. Possible values are finite, bucket (not quantified), and infinite.
:value :: :string
An indicator of the inventory available. Possible values are in_stock, limited, and out_of_stock. Will be present if and only if type is bucket.
Link to this section Summary
Link to this section Types
@type params() :: map()
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()