View Source ExOAPI.Stripe.Schemas.TaxRate (exoapi_stripe v0.1.4)
description: Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.
Related guide: Tax Rates.
:active :: :boolean
Defaults to true. When set to false, this tax rate cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
:country :: :string
Two-letter country code (ISO 3166-1 alpha-2).
:created :: :integer
Time at which the object was created. Measured in seconds since the Unix epoch.
:description :: :string
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
:display_name :: :string
The display name of the tax rates as it will appear to your customer on their receipt email, PDF, and the hosted invoice page.
:id :: :string
Unique identifier for the object.
:inclusive :: :boolean
This specifies if the tax rate is inclusive or exclusive.
:jurisdiction :: :string
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
:livemode :: :boolean
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
:metadata :: :map
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
:object :: :string
String representing the object's type. Objects of the same type share the same value.
:percentage :: :number
This represents the tax rate percent out of 100.
:state :: :string
ISO 3166-2 subdivision code, without country prefix. For example, "NY" for New York, United States.
:tax_type :: :string
The high-level tax type, such as vat or sales_tax.
Link to this section Summary
Link to this section Types
@type params() :: map()
@type t() :: %ExOAPI.Stripe.Schemas.TaxRate{ active: boolean() | nil, country: String.t() | nil, created: integer() | nil, description: String.t() | nil, display_name: String.t() | nil, id: String.t() | nil, inclusive: boolean() | nil, jurisdiction: String.t() | nil, livemode: boolean() | nil, metadata: map() | nil, object: :tax_rate | nil, percentage: float() | nil, state: String.t() | nil, tax_type: (:vat | :sales_tax | :rst | :qst | :pst | :jct | :hst | :gst) | nil }
Link to this section Functions
@spec changeset(t(), params()) :: Ecto.Changeset.t()